| delete_nonwear | R Documentation |
Deletes all periods marked as non-wear.
delete_nonwear(data)
data |
An |
This is an internal function, designed to be used inside the wrapper function remove_nonwear() that integrates all steps of detection, removal and inspection of accelerometer non-wear time.
The impactr_data object provided by data without the
wear column and with the non-wear time removed.
detect_nonwear(),
plot_nonwear(),
mark_nonwear(),
summarise_nonwear()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.