| detect_nonwear | R Documentation |
Implementation of the van Hees algorithm of non-wear detection.
detect_nonwear(data, window1, window2, threshold)
data |
An |
window1, window2 |
Windows size, in minutes, for the non-wear
detection algorithm. |
threshold |
Number of axes that need to meet the non-wear criteria. |
This is an internal function, designed to be used inside the wrapper function remove_nonwear() that integrates all steps of detection, removal and inspection of accelerometer non-wear time.
A named list of length 2 (stage1 and stage2) containing the binary
non-wear classification (0 is wear and 1 is non-wear) of each algorithm's
stage per window2 blocks.
plot_nonwear(),
mark_nonwear(),
summarise_nonwear(),
delete_nonwear()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.