View source: R/impactr_example.R
| impactr_example | R Documentation |
impactr comes with some example ActiGraph accelerometer raw data
files in its inst/extdata directory. This function make them easy to
access.
impactr_example(file = NULL)
file |
A character string with the file name. If |
If file = NULL, it returns the file names of the example
data files, else it returns the path to the example data.
impactr_example()
impactr_example("hip-raw.csv")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.