Learn R Programming

impactr (version 0.4.2)

is_impactr: Test if the object is from the impactr package

Description

Test if the object is from the impactr package

Usage

is_impactr_data(x)

is_impactr_peaks(x)

Value

TRUE if the object inherits the class being evaluated.

Arguments

x

An object.