Make all logs
Arguments
- .tbl
A tibble of data
- survey
The survey sheet of the Kobo tool
- check_list
A tibble of logical test to check for
- other
A character vector of the start of all other column names. E.g., other = "other_"
- id_col
Survey id, usually "uuid"
- ...
Columns to keep in the log, e.g. today, i_enum_id
See also
make_log for a log based on a logical test
make_log_from_check_list() for a log based on many logical tests
make_log_outlier() for a log based on outliers
make_log_other() for a log of others
Other functions to make logs:
make_log_from_check_list(),
make_log_other(),
make_log_outlier(),
make_log()