Learn R Programming

impactr (version 0.4.2)

delete_nonwear: Delete accelerometer non-wear time

Description

Deletes all periods marked as non-wear.

Usage

delete_nonwear(data)

Value

The impactr_data object provided by data without the wear column and with the non-wear time removed.

Arguments

data

An impactr_data object with the wear column, as obtained with mark_nonwear().

Details

This is an internal function, designed to be used inside the wrapper function remove_nonwear() that integrates all steps of detection, removal and inspection of accelerometer non-wear time.

See Also

detect_nonwear(), plot_nonwear(), mark_nonwear(), summarise_nonwear()