Deletes all periods marked as non-wear.
delete_nonwear(data)The impactr_data object provided by data without the
wear column and with the non-wear time removed.
An impactr_data object with the wear column, as
obtained with mark_nonwear().
This is an internal function, designed to be used inside the wrapper function remove_nonwear() that integrates all steps of detection, removal and inspection of accelerometer non-wear time.
detect_nonwear(),
plot_nonwear(),
mark_nonwear(),
summarise_nonwear()