Implementation of the van Hees algorithm of non-wear detection.
detect_nonwear(data, window1, window2, threshold)A named list of length 2 (stage1 and stage2) containing the binary
non-wear classification (0 is wear and 1 is non-wear) of each algorithm's
stage per window2 blocks.
An impactr_data object, as obtained with
read_acc().
Windows size, in minutes, for the non-wear
detection algorithm. window2 must be smaller than window1,
and window1 must be a multiple of window2.
Number of axes that need to meet the non-wear criteria.
This is an internal function, designed to be used inside the wrapper function remove_nonwear() that integrates all steps of detection, removal and inspection of accelerometer non-wear time.
plot_nonwear(),
mark_nonwear(),
summarise_nonwear(),
delete_nonwear()